#
# spec file for package qtfm
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           qtfm
Version:        6.2.1
Release:        2.4
Summary:        Qt File Manager
License:        GPL-2.0-or-later AND BSD-3-Clause
Group:          Productivity/File utilities
URL:            https://qtfm.eu
Source0:        https://github.com/rodlie/qtfm/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
# PATCH-FIX-UPSTREAM -- https://github.com/rodlie/qtfm/pull/174
Patch0:         0001-iconview-Fix-QPainterPath-path-has-incomplete-type.patch
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(Magick++)
BuildRequires:  pkgconfig(Qt5Concurrent)
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5DBus)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Widgets)
%if 0%{suse_version} >= 1550
BuildRequires:  ffmpeg-4-libavcodec-devel
BuildRequires:  ffmpeg-4-libavdevice-devel
BuildRequires:  ffmpeg-4-libavformat-devel
BuildRequires:  ffmpeg-4-libavutil-devel
BuildRequires:  ffmpeg-4-libswscale-devel
%else
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavdevice)
BuildRequires:  pkgconfig(libavformat)
BuildRequires:  pkgconfig(libavutil)
BuildRequires:  pkgconfig(libswscale)
%endif
Recommends:     adwaita-icon-theme
Recommends:     udisks2

%description
Lightweight file manager using Qt.

Features:
 * Desktop (theme/applications/mime) integration
 * Customizable interface
 * Powerful custom command system
 * Customizable key bindings
 * Drag & drop functionality
 * Tabs
 * Udisks support
 * System tray daemon

%prep
%autosetup -p1

%build
%qmake5 PREFIX=%{_prefix} CONFIG+=with_magick CONFIG+=magick7 CONFIG+=with_ffmpeg
%make_build

%install
%qmake5_install
%fdupes %{buildroot}/%{_datadir}
rm -rv %{buildroot}%{_datadir}/doc

%files
%license LICENSE
%doc AUTHORS ChangeLog README.md
%{_bindir}/qtfm
%{_bindir}/qtfm-tray
%{_datadir}/applications/qtfm.desktop
%dir %{_datadir}/icons/hicolor/{20x20,160x160}/{,apps}
%{_datadir}/icons/hicolor/*/apps/qtfm.??g
%{_sysconfdir}/xdg/autostart/qtfm-tray.desktop
%{_mandir}/man?/qtfm-tray.?%{?ext_man}
%{_mandir}/man?/qtfm.?%{?ext_man}

%changelog
* Sat Nov  5 2022 Christophe Giboudeaux <christophe@krop.fr>
- Explicitly use FFMpeg 4 to build qtfm. It doesn't support FFmpeg 5 yet.
* Tue Jun  8 2021 Michael Vetter <mvetter@suse.com>
- Update to 6.2.1:
  * fix remove symlink bug
  * fix build with Qt 5.15
  * fix memory leak
  * fix for "." start path
  * fix .desktop key/value parser
* Sat May  8 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 6.2.0:
  * imagemagick support (improved thumbnail support)
  * ffmpeg support (get thumbnails from audio/video)
  * settings: use decimal keys in config
  * settings: support filter mime types
  * (u)disks now supports disk labels (with device name as fallback)
  * bookmarks: added "link" option in file actions
  * support .config/mimeapps.list
  * tabbar: hide if only one tab
  * remove "open file" in context menu if selected item is folder
  * added "open in new tab" in context menu
  * fixed run executable on double click
  * fixed mount/umount issue with optical storage
  * fixed current drag mode
  * fix potential crash in close tab
  * show and run .desktop in file view
- Added 0001-iconview-Fix-QPainterPath-path-has-incomplete-type.patch
* Thu Apr 25 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 6.1.9:
  * clipboard changed: check pointer before read (fix segfault on
    wayland)
  * don't collapse tree on refresh
* Wed Mar 20 2019 mvetter@suse.com
- Update to 6.1.8:
  * Fix segfault if D-Bus is missing and QtFM is built with D-Bus support
  * Fix execute file path (with spaces)
* Tue Feb 12 2019 mvetter@suse.com
- Update to 6.1.7:
  * context menu fixes
  * settings dialog: fix performance issues on old CPUs
* Fri Feb  1 2019 mvetter@suse.com
- Update to 6.1.6:
  * progress dialog fix
  * path tab-completion. Thanks to @kubaroth[3]
  * completer handles expansion of ~ path. Thanks to @kubaroth[3]
  * support mouse back button
* Mon Dec 10 2018 Alexei Podvalsky <avvissu@yandex.by>
- Update to 6.1.5:
  * fix build if CONFIG+=no_dbus enabled
  * fixed broken multiple file copy/move instances
* Tue Nov 27 2018 mvetter@suse.com
- Update to 6.1.4:
  * fix potential config corruption. Thanks to @slackuser0xae34[3] for the patch
  * fix segfault on thumbnail update (view may have changed since loading thumbnails)
  * don't cut file(s) if moving to same directory in bookmarks
  * verify reply from udisks (avoid crash)
  * populate view if not watched
  * fix refresh view
  * improved performance
* Wed Oct 31 2018 Alexei Podvalsky <avvissu@yandex.by>
- Update to 6.1.3:
  * update grid on paste/remove
  * settings: don't show "launcher" in application dialog
  * added manual refresh of path
* Mon Oct  1 2018 Alexei Podvalsky <avvissu@yandex.by>
- Initial package
